ClientConfig

Struct ClientConfig 

pub struct ClientConfig {
    pub url: String,
    pub bearer_token: Option<String>,
    pub http_req_timeout: Duration,
    pub max_num_retries: u32,
    pub retry_base_ms: u64,
    pub retry_ceiling_ms: u64,
    pub proactive_rate_limit_sleep: bool,
}
Configuration for the Solana HyperSync client.

Fields

url: String

Base URL of the HyperSync server (e.g. “https://solana.hypersync.xyz”).

bearer_token: Option<String>

Bearer token for authenticated requests.

http_req_timeout: Duration

Timeout for individual HTTP requests.

max_num_retries: u32

Maximum number of retries per request.

retry_base_ms: u64

Base delay for exponential backoff retries.

retry_ceiling_ms: u64

Maximum delay for exponential backoff retries.

proactive_rate_limit_sleep: bool

Whether to proactively sleep when the rate limit is exhausted instead of sending requests that will be rejected with 429.

Enabled by default. Set to false to opt out and handle rate limits yourself.